
from pystof import Doc

stof = """

request: {
    #[server]
    /// Runs on the server, using any APIs the server provides.
    /// Anything we want sent back to us should go in the "Response" root.
    fn called_on_remote_server() {
        <Point>.plot(1.5m, 2.5cm);
        <Point>.plot(0.5km, 0.5m);
        <Point>.plot(1.25cm, 3m);
        <Point>.plot(1mm, 1um);

        <Point>.translate_all(300cm, -0.2m);
        Response.points = <Point>.points();
    }
}

#[main]
/// Runs here locally, sends the request to the server as BSTF (could use Stof too...).
fn main() {
    const bytes_body = blobify('bstf', self.request);
    const headers = { 'Content-Type': 'application/bstf' };
    const res = await Http.fetch('http://localhost:5000', 'post', bytes_body, headers);
    pln(Http.parse(res, new {}));
}

"""

def main():
    global stof
    doc = Doc()
    doc.parse(stof)
    doc.run()

if __name__ == '__main__':
    main()




from pystof import Doc

STOF = """
#[main]
fn main() {
    const name = Example.name('Stof,', 'with Python');
    pln(`Hello, ${name}!!`)
}
"""

def name(first, last):
    return first + ' ' + last

def main():
    doc = Doc()
    doc.lib('Example', 'name', name)
    doc.parse(STOF)
    doc.run()

if __name__ == "__main__":
    main()

# Output:
# Hello, Stof, with Python!!




from flask import Flask, request, Response
from pystof import Doc


app = Flask(__name__)
doc = Doc()
request_root = None
response_root = None


# The Stof required to make our server work.
# This includes a Request root, Response root, and a cleanup function.
base_path = 'src/py/examples/server/base.stof'
base_file = open(base_path, 'r')
BASE = base_file.read()
base_file.close()


# The Stof API our server offers for clients.
api_path = 'src/py/examples/server/api.stof'
api_file = open(api_path, 'r')
API = api_file.read()
api_file.close()


def init_doc():
    global request_root, response_root, BASE, API
    doc.parse(BASE)
    doc.parse(API)
    request_root = doc.get('Request', None)
    response_root = doc.get('Response', None)


@app.post('/')
def stof_entry():
    global doc, request_root, response_root

    # import into "Reqeust" root - a specific, known location in our document
    doc.binary_import(request.get_data(), 'bstf', request_root)
    doc.run('server')

    # export json from "Response" root - a specific, know location in our document
    res_json = doc.string_export('json', response_root)
    doc.run('cleanup') # remove any Request & Response data for the next pass
    request_root = doc.get('Request', None)
    response_root = doc.get('Response', None)

    return Response(res_json, mimetype='application/json')


if __name__ == '__main__':
    init_doc()
    app.run(debug=True)
